# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter_service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#voltha_protos/adapter_service.proto\x12\x0f\x61\x64\x61pter_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/health.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1dvoltha_protos/omci_test.proto\x1a\x1avoltha_protos/events.proto2\xf2\x15\n\x0e\x41\x64\x61pterService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12\x35\n\x0b\x41\x64optDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0fReconcileDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65leteDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x37\n\rDisableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eReEnableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0cRebootDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eSelfTestDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x42\n\x10GetOfpDeviceInfo\x12\x0e.device.Device\x1a\x1e.core_adapter.SwitchCapability\x12\x39\n\x0f\x43hildDeviceLost\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x32\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x33\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fUpdateFlowsBulk\x12\x17.core_adapter.BulkFlows\x1a\x16.google.protobuf.Empty\x12R\n\x18UpdateFlowsIncrementally\x12\x1e.core_adapter.IncrementalFlows\x1a\x16.google.protobuf.Empty\x12@\n\rSendPacketOut\x12\x17.core_adapter.PacketOut\x1a\x16.google.protobuf.Empty\x12\x45\n\x0eUpdatePmConfig\x12\x1b.core_adapter.PmConfigsInfo\x1a\x16.google.protobuf.Empty\x12S\n\x10\x44ownloadOnuImage\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\x12L\n\x11GetOnuImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\x14\x41\x62ortOnuImageUpgrade\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12-\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\x12K\n\x10\x41\x63tivateOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12I\n\x0e\x43ommitOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\rDownloadImage\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12X\n\x16GetImageDownloadStatus\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x43\x61ncelImageDownload\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x41\x63tivateImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12S\n\x11RevertImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12;\n\rStartOmciTest\x12\x16.core_adapter.OMCITest\x1a\x12.omci.TestResponse\x12J\n\rSimulateAlarm\x12\".core_adapter.SimulateAlarmMessage\x1a\x15.common.OperationResp\x12;\n\rSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12=\n\x0fUnSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12H\n\x0bGetExtValue\x12 .core_adapter.GetExtValueMessage\x1a\x17.extension.ReturnValues\x12G\n\x0bSetExtValue\x12 .core_adapter.SetExtValueMessage\x1a\x16.google.protobuf.Empty\x12U\n\x0eGetSingleValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12U\n\x0eSetSingleValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponse\x12:\n\x10\x44isableOnuDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0f\x45nableOnuDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12Q\n\x16\x44isableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\x12P\n\x15\x45nableOnuSerialNumber\x12\x1f.device.OnuSerialNumberOnOLTPon\x1a\x16.google.protobuf.Empty\x12<\n\x0cUpdateDevice\x12\x14.device.UpdateDevice\x1a\x16.google.protobuf.EmptyBt\n#org.opencord.voltha.adapter_serviceB\x14VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.adapter_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#org.opencord.voltha.adapter_serviceB\024VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_service'
  _globals['_ADAPTERSERVICE'].methods_by_name['DownloadImage']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['DownloadImage']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['GetImageDownloadStatus']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['GetImageDownloadStatus']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['CancelImageDownload']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['CancelImageDownload']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['ActivateImageUpdate']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['ActivateImageUpdate']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE'].methods_by_name['RevertImageUpdate']._options = None
  _globals['_ADAPTERSERVICE'].methods_by_name['RevertImageUpdate']._serialized_options = b'\210\002\001'
  _globals['_ADAPTERSERVICE']._serialized_start=323
  _globals['_ADAPTERSERVICE']._serialized_end=3125
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_test.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvoltha_protos/omci_test.proto\x12\x04omci\"+\n\x0fOmciTestRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"u\n\x0cTestResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.omci.TestResponse.TestResponseResult\".\n\x12TestResponseResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x42H\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.omci_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci'
  _globals['_OMCITESTREQUEST']._serialized_start=39
  _globals['_OMCITESTREQUEST']._serialized_end=82
  _globals['_TESTRESPONSE']._serialized_start=84
  _globals['_TESTRESPONSE']._serialized_end=201
  _globals['_TESTRESPONSE_TESTRESPONSERESULT']._serialized_start=155
  _globals['_TESTRESPONSE_TESTRESPONSERESULT']._serialized_end=201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_user_profile.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%voltha_protos/voip_user_profile.proto\x12\x11voip_user_profile\x1a\x1cgoogle/api/annotations.proto\"b\n\x16VoipUserProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x0fvoipUserProfile\x18\x02 \x01(\x0b\x32\".voip_user_profile.VoipUserProfile\"\xa7\x01\n\x0fVoipUserProfile\x12\x1c\n\x14voipSystemProfileKey\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\r\n\x05proxy\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\r\x12\x16\n\x0esipDisplayName\x18\x07 \x01(\t\x12\r\n\x05realm\x18\x08 \x01(\tBb\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voip_user_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profile'
  _globals['_VOIPUSERPROFILEREQUEST']._serialized_start=90
  _globals['_VOIPUSERPROFILEREQUEST']._serialized_end=188
  _globals['_VOIPUSERPROFILE']._serialized_start=191
  _globals['_VOIPUSERPROFILE']._serialized_end=358
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/extensions.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evoltha_protos/extensions.proto\x12\textension\x1a\x1evoltha_protos/ext_config.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\"L\n\x08ValueSet\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x0c\x61larm_config\x18\x02 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x42\x07\n\x05value\",\n\tValueType\"\x1f\n\x04Type\x12\t\n\x05\x45MPTY\x10\x00\x12\x0c\n\x08\x44ISTANCE\x10\x01\"F\n\x0eValueSpecifier\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0e\x32\x19.extension.ValueType.Type\"Q\n\x0cReturnValues\x12\x0b\n\x03Set\x18\x01 \x01(\r\x12\x13\n\x0bUnsupported\x18\x02 \x01(\r\x12\r\n\x05\x45rror\x18\x03 \x01(\r\x12\x10\n\x08\x44istance\x18\x04 \x01(\r\")\n\x12GetDistanceRequest\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\"\'\n\x13GetDistanceResponse\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\"(\n\x14GetOnuUniInfoRequest\x12\x10\n\x08uniIndex\x18\x01 \x01(\r\"\xc1\x04\n\x15GetOnuUniInfoResponse\x12\x46\n\x08\x61\x64mState\x18\x01 \x01(\x0e\x32\x34.extension.GetOnuUniInfoResponse.AdministrativeState\x12\x44\n\toperState\x18\x02 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.OperationalState\x12\x44\n\tconfigInd\x18\x03 \x01(\x0e\x32\x31.extension.GetOnuUniInfoResponse.ConfigurationInd\"\xc2\x01\n\x10\x43onfigurationInd\x12\n\n\x06UNKOWN\x10\x00\x12\x12\n\x0eTEN_BASE_T_FDX\x10\x01\x12\x16\n\x12HUNDRED_BASE_T_FDX\x10\x02\x12\x18\n\x14GIGABIT_ETHERNET_FDX\x10\x03\x12\x16\n\x12TEN_G_ETHERNET_FDX\x10\x04\x12\x12\n\x0eTEN_BASE_T_HDX\x10\x05\x12\x16\n\x12HUNDRED_BASE_T_HDX\x10\x06\x12\x18\n\x14GIGABIT_ETHERNET_HDX\x10\x07\"G\n\x13\x41\x64ministrativeState\x12\x16\n\x12\x41\x44MSTATE_UNDEFINED\x10\x00\x12\n\n\x06LOCKED\x10\x01\x12\x0c\n\x08UNLOCKED\x10\x02\"F\n\x10OperationalState\x12\x17\n\x13OPERSTATE_UNDEFINED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xa5\x01\n\x12GetOltPortCounters\x12\x0e\n\x06portNo\x18\x01 \x01(\r\x12\x38\n\x08portType\x18\x02 \x01(\x0e\x32&.extension.GetOltPortCounters.PortType\"E\n\x08PortType\x12\x10\n\x0cPort_UNKNOWN\x10\x00\x12\x15\n\x11Port_ETHERNET_NNI\x10\x01\x12\x10\n\x0cPort_PON_OLT\x10\x02\"\xa4\x02\n\x1aGetOltPortCountersResponse\x12\x0f\n\x07txBytes\x18\x01 \x01(\x04\x12\x0f\n\x07rxBytes\x18\x02 \x01(\x04\x12\x11\n\ttxPackets\x18\x03 \x01(\x04\x12\x11\n\trxPackets\x18\x04 \x01(\x04\x12\x16\n\x0etxErrorPackets\x18\x05 \x01(\x04\x12\x16\n\x0erxErrorPackets\x18\x06 \x01(\x04\x12\x16\n\x0etxBcastPackets\x18\x07 \x01(\x04\x12\x16\n\x0erxBcastPackets\x18\x08 \x01(\x04\x12\x16\n\x0etxUcastPackets\x18\t \x01(\x04\x12\x16\n\x0erxUcastPackets\x18\n \x01(\x04\x12\x16\n\x0etxMcastPackets\x18\x0b \x01(\x04\x12\x16\n\x0erxMcastPackets\x18\x0c \x01(\x04\"=\n\x14GetOnuPonOpticalInfo\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\xa5\x01\n\x1cGetOnuPonOpticalInfoResponse\x12\x18\n\x10powerFeedVoltage\x18\x01 \x01(\x02\x12\x1c\n\x14receivedOpticalPower\x18\x02 \x01(\x02\x12\x1e\n\x16meanOpticalLaunchPower\x18\x03 \x01(\x02\x12\x18\n\x10laserBiasCurrent\x18\x04 \x01(\x02\x12\x13\n\x0btemperature\x18\x05 \x01(\x02\"\xa4\x01\n\x1fGetOnuEthernetBridgePortHistory\x12G\n\tdirection\x18\x01 \x01(\x0e\x32\x34.extension.GetOnuEthernetBridgePortHistory.Direction\"8\n\tDirection\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08UPSTREAM\x10\x01\x12\x0e\n\nDOWNSTREAM\x10\x02\"\x96\x03\n\'GetOnuEthernetBridgePortHistoryResponse\x12\x12\n\ndropEvents\x18\x01 \x01(\r\x12\x0e\n\x06octets\x18\x02 \x01(\r\x12\x0f\n\x07packets\x18\x03 \x01(\r\x12\x18\n\x10\x62roadcastPackets\x18\x04 \x01(\r\x12\x18\n\x10multicastPackets\x18\x05 \x01(\r\x12\x19\n\x11\x63rcErroredPackets\x18\x06 \x01(\r\x12\x18\n\x10undersizePackets\x18\x07 \x01(\r\x12\x17\n\x0foversizePackets\x18\x08 \x01(\r\x12\x17\n\x0fpackets64octets\x18\t \x01(\r\x12\x1c\n\x14packets65To127octets\x18\n \x01(\r\x12\x1d\n\x15packets128To255Octets\x18\x0b \x01(\r\x12\x1d\n\x15packets256To511octets\x18\x0c \x01(\r\x12\x1e\n\x16packets512To1023octets\x18\r \x01(\r\x12\x1f\n\x17packets1024To1518octets\x18\x0e \x01(\r\"E\n\x1cGetOnuAllocGemHistoryRequest\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\x8c\x02\n\x15OnuGemPortHistoryData\x12\r\n\x05gemId\x18\x01 \x01(\r\x12\x1c\n\x14transmittedGEMFrames\x18\x02 \x01(\r\x12\x19\n\x11receivedGEMFrames\x18\x03 \x01(\r\x12 \n\x14receivedPayloadBytes\x18\x04 \x01(\rB\x02\x18\x01\x12#\n\x17transmittedPayloadBytes\x18\x05 \x01(\rB\x02\x18\x01\x12\x1b\n\x13\x65ncryptionKeyErrors\x18\x06 \x01(\r\x12!\n\x19received_payload_bytes_64\x18\x07 \x01(\x06\x12$\n\x1ctransmitted_payload_bytes_64\x18\x08 \x01(\x06\"7\n\x13OnuAllocHistoryData\x12\x0f\n\x07\x61llocId\x18\x01 \x01(\r\x12\x0f\n\x07rxBytes\x18\x02 \x01(\r\"\x87\x01\n\x16OnuAllocGemHistoryData\x12\x36\n\x0eonuAllocIdInfo\x18\x01 \x01(\x0b\x32\x1e.extension.OnuAllocHistoryData\x12\x35\n\x0bgemPortInfo\x18\x02 \x03(\x0b\x32 .extension.OnuGemPortHistoryData\"b\n\x1dGetOnuAllocGemHistoryResponse\x12\x41\n\x16onuAllocGemHistoryData\x18\x01 \x03(\x0b\x32!.extension.OnuAllocGemHistoryData\"9\n\x10GetOnuFecHistory\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\xb1\x02\n\x18GetOnuFecHistoryResponse\x12\x1a\n\x0e\x63orrectedBytes\x18\x01 \x01(\rB\x02\x18\x01\x12\x1e\n\x12\x63orrectedCodeWords\x18\x02 \x01(\rB\x02\x18\x01\x12\x12\n\nfecSeconds\x18\x03 \x01(\r\x12\x1a\n\x0etotalCodeWords\x18\x04 \x01(\rB\x02\x18\x01\x12\"\n\x16uncorrectableCodeWords\x18\x05 \x01(\rB\x02\x18\x01\x12\x1e\n\x16\x66\x65\x63_corrected_bytes_64\x18\x06 \x01(\x06\x12#\n\x1b\x66\x65\x63_corrected_code_words_64\x18\x07 \x01(\x06\x12\x1b\n\x13total_code_words_64\x18\x08 \x01(\x06\x12#\n\x1buncorrectable_code_words_64\x18\t \x01(\x06\"8\n\x15GetOnuCountersRequest\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"o\n%GetOmciEthernetFrameExtendedPmRequest\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\x12\x12\n\x08uniIndex\x18\x02 \x01(\rH\x00\x12\r\n\x05reset\x18\x03 \x01(\x08\x42\x0e\n\x0cis_uni_index\"4\n\x11GetRxPowerRequest\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\":\n\x14GetOltRxPowerRequest\x12\x12\n\nport_label\x18\x01 \x01(\t\x12\x0e\n\x06onu_sn\x18\x02 \x01(\t\"G\n\x12GetPonStatsRequest\x12\x13\n\tportLabel\x18\x01 \x01(\tH\x00\x12\x10\n\x06portId\x18\x02 \x01(\x07H\x00\x42\n\n\x08portInfo\"V\n\x13GetPonStatsResponse\x12\x0f\n\x07ponPort\x18\x01 \x01(\r\x12.\n\x0eportStatistics\x18\x02 \x01(\x0b\x32\x16.common.PortStatistics\"G\n\x12GetNNIStatsRequest\x12\x13\n\tportLabel\x18\x01 \x01(\tH\x00\x12\x10\n\x06portId\x18\x02 \x01(\x07H\x00\x42\n\n\x08portInfo\"V\n\x13GetNNIStatsResponse\x12\x0f\n\x07nniPort\x18\x01 \x01(\r\x12.\n\x0eportStatistics\x18\x02 \x01(\x0b\x32\x16.common.PortStatistics\":\n\x19GetOnuStatsFromOltRequest\x12\x0e\n\x06intfId\x18\x01 \x01(\x07\x12\r\n\x05onuId\x18\x02 \x01(\x07\"n\n\x15OnuGemPortInfoFromOlt\x12\r\n\x05gemId\x18\x01 \x01(\r\x12\x11\n\trxPackets\x18\x02 \x01(\x04\x12\x0f\n\x07rxBytes\x18\x03 \x01(\x04\x12\x11\n\ttxPackets\x18\x04 \x01(\x04\x12\x0f\n\x07txBytes\x18\x05 \x01(\x04\"9\n\x15OnuAllocIdInfoFromOlt\x12\x0f\n\x07\x61llocId\x18\x01 \x01(\r\x12\x0f\n\x07rxBytes\x18\x02 \x01(\x04\"\x8f\x01\n\x1fOnuAllocGemStatsFromOltResponse\x12\x35\n\x0b\x61llocIdInfo\x18\x01 \x01(\x0b\x32 .extension.OnuAllocIdInfoFromOlt\x12\x35\n\x0bgemPortInfo\x18\x02 \x03(\x0b\x32 .extension.OnuGemPortInfoFromOlt\"c\n\x1aGetOnuStatsFromOltResponse\x12\x45\n\x11\x61llocGemStatsInfo\x18\x01 \x03(\x0b\x32*.extension.OnuAllocGemStatsFromOltResponse\"\x92\n\n\x16GetOnuCountersResponse\x12\x11\n\x07intf_id\x18\x01 \x01(\x07H\x00\x12\x10\n\x06onu_id\x18\x02 \x01(\x07H\x01\x12\x18\n\x0epositive_drift\x18\x03 \x01(\x06H\x02\x12\x18\n\x0enegative_drift\x18\x04 \x01(\x06H\x03\x12\"\n\x18\x64\x65limiter_miss_detection\x18\x05 \x01(\x06H\x04\x12\x14\n\nbip_errors\x18\x06 \x01(\x06H\x05\x12\x13\n\tbip_units\x18\x07 \x01(\x06H\x06\x12\x1f\n\x15\x66\x65\x63_corrected_symbols\x18\x08 \x01(\x06H\x07\x12!\n\x17\x66\x65\x63_codewords_corrected\x18\t \x01(\x06H\x08\x12%\n\x1b\x66\x65\x63_codewords_uncorrectable\x18\n \x01(\x06H\t\x12\x17\n\rfec_codewords\x18\x0b \x01(\x06H\n\x12\x1d\n\x13\x66\x65\x63_corrected_units\x18\x0c \x01(\x06H\x0b\x12\x19\n\x0fxgem_key_errors\x18\r \x01(\x06H\x0c\x12\x13\n\txgem_loss\x18\x0e \x01(\x06H\r\x12\x19\n\x0frx_ploams_error\x18\x0f \x01(\x06H\x0e\x12\x1c\n\x12rx_ploams_non_idle\x18\x10 \x01(\x06H\x0f\x12\x11\n\x07rx_omci\x18\x11 \x01(\x06H\x10\x12\x11\n\x07tx_omci\x18\x12 \x01(\x06H\x11\x12#\n\x19rx_omci_packets_crc_error\x18\x13 \x01(\x06H\x12\x12\x12\n\x08rx_bytes\x18\x14 \x01(\x06H\x13\x12\x14\n\nrx_packets\x18\x15 \x01(\x06H\x14\x12\x12\n\x08tx_bytes\x18\x16 \x01(\x06H\x15\x12\x14\n\ntx_packets\x18\x17 \x01(\x06H\x16\x12\x16\n\x0c\x62\x65r_reported\x18\x18 \x01(\x06H\x17\x12\x15\n\x0blcdg_errors\x18\x19 \x01(\x06H\x18\x12\x14\n\nrdi_errors\x18\x1a \x01(\x06H\x19\x12\x13\n\ttimestamp\x18\x1b \x01(\x07H\x1a\x12\x14\n\nhec_errors\x18\x1c \x01(\x06H\x1b\x42\x0c\n\nis_intf_idB\x0b\n\tis_onu_idB\x13\n\x11is_positive_driftB\x13\n\x11is_negative_driftB\x1d\n\x1bis_delimiter_miss_detectionB\x0f\n\ris_bip_errorsB\x0e\n\x0cis_bip_unitsB\x1a\n\x18is_fec_corrected_symbolsB\x1c\n\x1ais_fec_codewords_correctedB \n\x1eis_fec_codewords_uncorrectableB\x12\n\x10is_fec_codewordsB\x18\n\x16is_fec_corrected_unitsB\x14\n\x12is_xgem_key_errorsB\x0e\n\x0cis_xgem_lossB\x14\n\x12is_rx_ploams_errorB\x17\n\x15is_rx_ploams_non_idleB\x0c\n\nis_rx_omciB\x0c\n\nis_tx_omciB\x1e\n\x1cis_rx_omci_packets_crc_errorB\r\n\x0bis_rx_bytesB\x0f\n\ris_rx_packetsB\r\n\x0bis_tx_bytesB\x0f\n\ris_tx_packetsB\x11\n\x0fis_ber_reportedB\x10\n\x0eis_lcdg_errorsB\x0f\n\ris_rdi_errorsB\x0e\n\x0cis_timestampB\x0f\n\ris_hec_errors\"\x9b\x03\n\x1bOmciEthernetFrameExtendedPm\x12\x13\n\x0b\x64rop_events\x18\x01 \x01(\x06\x12\x0e\n\x06octets\x18\x02 \x01(\x06\x12\x0e\n\x06\x66rames\x18\x03 \x01(\x06\x12\x18\n\x10\x62roadcast_frames\x18\x04 \x01(\x06\x12\x18\n\x10multicast_frames\x18\x05 \x01(\x06\x12\x1a\n\x12\x63rc_errored_frames\x18\x06 \x01(\x06\x12\x18\n\x10undersize_frames\x18\x07 \x01(\x06\x12\x17\n\x0foversize_frames\x18\x08 \x01(\x06\x12\x18\n\x10\x66rames_64_octets\x18\t \x01(\x06\x12\x1f\n\x17\x66rames_65_to_127_octets\x18\n \x01(\x06\x12 \n\x18\x66rames_128_to_255_octets\x18\x0b \x01(\x06\x12 \n\x18\x66rames_256_to_511_octets\x18\x0c \x01(\x06\x12!\n\x19\x66rames_512_to_1023_octets\x18\r \x01(\x06\x12\"\n\x1a\x66rames_1024_to_1518_octets\x18\x0e \x01(\x06\"\xba\x02\n&GetOmciEthernetFrameExtendedPmResponse\x12\x38\n\x08upstream\x18\x01 \x01(\x0b\x32&.extension.OmciEthernetFrameExtendedPm\x12:\n\ndownstream\x18\x02 \x01(\x0b\x32&.extension.OmciEthernetFrameExtendedPm\x12h\n&omci_ethernet_frame_extended_pm_format\x18\x03 \x01(\x0e\x32\x38.extension.GetOmciEthernetFrameExtendedPmResponse.Format\"0\n\x06\x46ormat\x12\x12\n\x0eTHIRTY_TWO_BIT\x10\x00\x12\x12\n\x0eSIXTY_FOUR_BIT\x10\x01\"P\n\x07RxPower\x12\x0e\n\x06onu_sn\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x13\n\x0b\x66\x61il_reason\x18\x03 \x01(\t\x12\x10\n\x08rx_power\x18\x04 \x01(\x01\"Q\n\x15GetOltRxPowerResponse\x12\x12\n\nport_label\x18\x01 \x01(\t\x12$\n\x08rx_power\x18\x02 \x03(\x0b\x32\x12.extension.RxPower\"l\n\x12GetRxPowerResponse\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61il_reason\x18\x04 \x01(\t\x12\x10\n\x08rx_power\x18\x05 \x01(\x01\"C\n\x1aGetOnuOmciTxRxStatsRequest\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\xc0\x02\n\x1bGetOnuOmciTxRxStatsResponse\x12\x19\n\x11\x62\x61se_tx_ar_frames\x18\x01 \x01(\r\x12\x19\n\x11\x62\x61se_rx_ak_frames\x18\x02 \x01(\r\x12\x1c\n\x14\x62\x61se_tx_no_ar_frames\x18\x03 \x01(\r\x12\x1c\n\x14\x62\x61se_rx_no_ak_frames\x18\x04 \x01(\r\x12\x18\n\x10\x65xt_tx_ar_frames\x18\x05 \x01(\r\x12\x18\n\x10\x65xt_rx_ak_frames\x18\x06 \x01(\r\x12\x1b\n\x13\x65xt_tx_no_ar_frames\x18\x07 \x01(\r\x12\x1b\n\x13\x65xt_rx_no_ak_frames\x18\x08 \x01(\r\x12\x1f\n\x17tx_omci_counter_retries\x18\t \x01(\r\x12 \n\x18tx_omci_counter_timeouts\x18\n \x01(\r\"F\n\x1dGetOnuOmciActiveAlarmsRequest\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"U\n\tAlarmData\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12\x13\n\x0binstance_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"M\n\x1eGetOnuOmciActiveAlarmsResponse\x12+\n\ractive_alarms\x18\x01 \x03(\x0b\x32\x14.extension.AlarmData\"\xb8\x01\n!GetOffloadedAppsStatisticsRequest\x12K\n\x08statsFor\x18\x01 \x01(\x0e\x32\x39.extension.GetOffloadedAppsStatisticsRequest.OffloadedApp\"F\n\x0cOffloadedApp\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07PPPoeIA\x10\x01\x12\x0c\n\x08\x44HCPv4RA\x10\x02\x12\x0c\n\x08\x44HCPv6RA\x10\x03\"\x90\x0f\n\"GetOffloadedAppsStatisticsResponse\x12T\n\rdhcpv4RaStats\x18\x01 \x01(\x0b\x32;.extension.GetOffloadedAppsStatisticsResponse.DHCPv4RAStatsH\x00\x12T\n\rdhcpv6RaStats\x18\x02 \x01(\x0b\x32;.extension.GetOffloadedAppsStatisticsResponse.DHCPv6RAStatsH\x00\x12R\n\x0cpppoeIaStats\x18\x03 \x01(\x0b\x32:.extension.GetOffloadedAppsStatisticsResponse.PPPoeIAStatsH\x00\x1a\xfe\x03\n\rDHCPv4RAStats\x12\"\n\x1ain_bad_packets_from_client\x18\x01 \x01(\r\x12\"\n\x1ain_bad_packets_from_server\x18\x02 \x01(\r\x12\x1e\n\x16in_packets_from_client\x18\x03 \x01(\r\x12\x1e\n\x16in_packets_from_server\x18\x04 \x01(\r\x12\x1d\n\x15out_packets_to_server\x18\x05 \x01(\r\x12\x1d\n\x15out_packets_to_client\x18\x06 \x01(\r\x12,\n$option_82_inserted_packets_to_server\x18\x07 \x01(\r\x12+\n#option_82_removed_packets_to_client\x18\x08 \x01(\r\x12(\n option_82_not_inserted_to_server\x18\t \x01(\r\x12j\n\x10\x61\x64\x64itional_stats\x18\n \x03(\x0b\x32P.extension.GetOffloadedAppsStatisticsResponse.DHCPv4RAStats.AdditionalStatsEntry\x1a\x36\n\x14\x41\x64\x64itionalStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xbf\x04\n\rDHCPv6RAStats\x12\"\n\x1ain_bad_packets_from_client\x18\x01 \x01(\r\x12\"\n\x1ain_bad_packets_from_server\x18\x02 \x01(\r\x12,\n$option_17_inserted_packets_to_server\x18\x03 \x01(\r\x12+\n#option_17_removed_packets_to_client\x18\x04 \x01(\r\x12,\n$option_18_inserted_packets_to_server\x18\x05 \x01(\r\x12+\n#option_18_removed_packets_to_client\x18\x06 \x01(\r\x12,\n$option_37_inserted_packets_to_server\x18\x07 \x01(\r\x12+\n#option_37_removed_packets_to_client\x18\x08 \x01(\r\x12\x31\n)outgoing_mtu_exceeded_packets_from_client\x18\t \x01(\r\x12j\n\x10\x61\x64\x64itional_stats\x18\n \x03(\x0b\x32P.extension.GetOffloadedAppsStatisticsResponse.DHCPv6RAStats.AdditionalStatsEntry\x1a\x36\n\x14\x41\x64\x64itionalStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x9d\x04\n\x0cPPPoeIAStats\x12$\n\x1cin_error_packets_from_client\x18\x01 \x01(\r\x12$\n\x1cin_error_packets_from_server\x18\x02 \x01(\r\x12\x1e\n\x16in_packets_from_client\x18\x03 \x01(\r\x12\x1e\n\x16in_packets_from_server\x18\x04 \x01(\r\x12\x1d\n\x15out_packets_to_server\x18\x05 \x01(\r\x12\x1d\n\x15out_packets_to_client\x18\x06 \x01(\r\x12\x36\n.vendor_specific_tag_inserted_packets_to_server\x18\x07 \x01(\r\x12\x35\n-vendor_specific_tag_removed_packets_to_client\x18\x08 \x01(\r\x12\x31\n)outgoing_mtu_exceeded_packets_from_client\x18\t \x01(\r\x12i\n\x10\x61\x64\x64itional_stats\x18\n \x03(\x0b\x32O.extension.GetOffloadedAppsStatisticsResponse.PPPoeIAStats.AdditionalStatsEntry\x1a\x36\n\x14\x41\x64\x64itionalStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05stats\"\x93\x08\n\x0fGetValueRequest\x12\x31\n\x08\x64istance\x18\x01 \x01(\x0b\x32\x1d.extension.GetDistanceRequestH\x00\x12\x32\n\x07uniInfo\x18\x02 \x01(\x0b\x32\x1f.extension.GetOnuUniInfoRequestH\x00\x12\x34\n\x0boltPortInfo\x18\x03 \x01(\x0b\x32\x1d.extension.GetOltPortCountersH\x00\x12\x39\n\x0eonuOpticalInfo\x18\x04 \x01(\x0b\x32\x1f.extension.GetOnuPonOpticalInfoH\x00\x12\x43\n\rethBridgePort\x18\x05 \x01(\x0b\x32*.extension.GetOnuEthernetBridgePortHistoryH\x00\x12\x31\n\nfecHistory\x18\x06 \x01(\x0b\x32\x1b.extension.GetOnuFecHistoryH\x00\x12\x36\n\nonuPonInfo\x18\x07 \x01(\x0b\x32 .extension.GetOnuCountersRequestH\x00\x12\x43\n\x07onuInfo\x18\x08 \x01(\x0b\x32\x30.extension.GetOmciEthernetFrameExtendedPmRequestH\x00\x12/\n\x07rxPower\x18\t \x01(\x0b\x32\x1c.extension.GetRxPowerRequestH\x00\x12=\n\x0conuOmciStats\x18\n \x01(\x0b\x32%.extension.GetOnuOmciTxRxStatsRequestH\x00\x12\x35\n\noltRxPower\x18\x0b \x01(\x0b\x32\x1f.extension.GetOltRxPowerRequestH\x00\x12\x43\n\x0fonuActiveAlarms\x18\x0c \x01(\x0b\x32(.extension.GetOnuOmciActiveAlarmsRequestH\x00\x12J\n\x12offloadedAppsStats\x18\r \x01(\x0b\x32,.extension.GetOffloadedAppsStatisticsRequestH\x00\x12\x43\n\x10onuAllocGemStats\x18\x0e \x01(\x0b\x32\'.extension.GetOnuAllocGemHistoryRequestH\x00\x12?\n\x0fonuStatsFromOlt\x18\x0f \x01(\x0b\x32$.extension.GetOnuStatsFromOltRequestH\x00\x12\x34\n\x0boltPonStats\x18\x10 \x01(\x0b\x32\x1d.extension.GetPonStatsRequestH\x00\x12\x34\n\x0boltNniStats\x18\x11 \x01(\x0b\x32\x1d.extension.GetNNIStatsRequestH\x00\x42\t\n\x07request\"\xc2\x0b\n\x10GetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.GetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.GetValueResponse.ErrorReason\x12\x32\n\x08\x64istance\x18\x03 \x01(\x0b\x32\x1e.extension.GetDistanceResponseH\x00\x12\x33\n\x07uniInfo\x18\x04 \x01(\x0b\x32 .extension.GetOnuUniInfoResponseH\x00\x12=\n\x0cportCoutners\x18\x05 \x01(\x0b\x32%.extension.GetOltPortCountersResponseH\x00\x12\x41\n\x0eonuOpticalInfo\x18\x06 \x01(\x0b\x32\'.extension.GetOnuPonOpticalInfoResponseH\x00\x12O\n\x11\x65thBridgePortInfo\x18\x07 \x01(\x0b\x32\x32.extension.GetOnuEthernetBridgePortHistoryResponseH\x00\x12\x39\n\nfecHistory\x18\x08 \x01(\x0b\x32#.extension.GetOnuFecHistoryResponseH\x00\x12;\n\x0eonuPonCounters\x18\t \x01(\x0b\x32!.extension.GetOnuCountersResponseH\x00\x12H\n\x0bonuCounters\x18\n \x01(\x0b\x32\x31.extension.GetOmciEthernetFrameExtendedPmResponseH\x00\x12\x30\n\x07rxPower\x18\x0b \x01(\x0b\x32\x1d.extension.GetRxPowerResponseH\x00\x12>\n\x0conuOmciStats\x18\x0c \x01(\x0b\x32&.extension.GetOnuOmciTxRxStatsResponseH\x00\x12\x36\n\noltRxPower\x18\r \x01(\x0b\x32 .extension.GetOltRxPowerResponseH\x00\x12\x44\n\x0fonuActiveAlarms\x18\x0e \x01(\x0b\x32).extension.GetOnuOmciActiveAlarmsResponseH\x00\x12K\n\x12offloadedAppsStats\x18\x0f \x01(\x0b\x32-.extension.GetOffloadedAppsStatisticsResponseH\x00\x12L\n\x18onuAllocGemStatsResponse\x18\x10 \x01(\x0b\x32(.extension.GetOnuAllocGemHistoryResponseH\x00\x12H\n\x17onuStatsFromOltResponse\x18\x11 \x01(\x0b\x32%.extension.GetOnuStatsFromOltResponseH\x00\x12=\n\x13oltPonStatsResponse\x18\x12 \x01(\x0b\x32\x1e.extension.GetPonStatsResponseH\x00\x12=\n\x13oltNniStatsResponse\x18\x13 \x01(\x0b\x32\x1e.extension.GetNNIStatsResponseH\x00\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"\xad\x01\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\x12\x15\n\x11INVALID_DEVICE_ID\x10\x02\x12\x15\n\x11INVALID_PORT_TYPE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x14\n\x10INVALID_REQ_TYPE\x10\x05\x12\x12\n\x0eINTERNAL_ERROR\x10\x06\x12\x12\n\x0eINVALID_DEVICE\x10\x07\x42\n\n\x08response\"o\n\x10\x41ppOffloadConfig\x12\x16\n\x0e\x65nableDHCPv4RA\x18\x01 \x01(\x08\x12\x16\n\x0e\x65nableDHCPv6RA\x18\x02 \x01(\x08\x12\x15\n\renablePPPoEIA\x18\x03 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65ssNodeID\x18\x04 \x01(\t\"\xbc\x01\n\x13\x41ppOffloadOnuConfig\x12\x13\n\x0bonuDeviceId\x18\x01 \x01(\t\x12?\n\nperUniInfo\x18\x05 \x03(\x0b\x32+.extension.AppOffloadOnuConfig.PerUniConfig\x1aO\n\x0cPerUniConfig\x12\x15\n\ragentRemoteID\x18\x02 \x01(\t\x12\x16\n\x0e\x61gentCircuitID\x18\x03 \x01(\t\x12\x10\n\x08onuUniId\x18\x04 \x01(\r\"\xc6\x01\n\x0fSetValueRequest\x12+\n\x0c\x61larm_config\x18\x01 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x12\x39\n\x12\x61pp_offload_config\x18\x02 \x01(\x0b\x32\x1b.extension.AppOffloadConfigH\x00\x12@\n\x16\x61pp_offload_onu_config\x18\x03 \x01(\x0b\x32\x1e.extension.AppOffloadOnuConfigH\x00\x42\t\n\x07request\"\xb1\x02\n\x10SetValueResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".extension.SetValueResponse.Status\x12:\n\terrReason\x18\x02 \x01(\x0e\x32\'.extension.SetValueResponse.ErrorReason\"1\n\x06Status\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"z\n\x0b\x45rrorReason\x12\x14\n\x10REASON_UNDEFINED\x10\x00\x12\x0f\n\x0bUNSUPPORTED\x10\x01\x12\x15\n\x11INVALID_DEVICE_ID\x10\x02\x12\x19\n\x15INVALID_ONU_DEVICE_ID\x10\x03\x12\x12\n\x0eINVALID_UNI_ID\x10\x04\"V\n\x15SingleGetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.GetValueRequest\"G\n\x16SingleGetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.GetValueResponse\"V\n\x15SingleSetValueRequest\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12+\n\x07request\x18\x02 \x01(\x0b\x32\x1a.extension.SetValueRequest\"G\n\x16SingleSetValueResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.extension.SetValueResponse2\xb3\x01\n\tExtension\x12R\n\x0bGetExtValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12R\n\x0bSetExtValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponseBR\n\x1dorg.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v5/go/extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.extensions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035org.opencord.voltha.extensionZ1github.com/opencord/voltha-protos/v5/go/extension'
  _globals['_ONUGEMPORTHISTORYDATA'].fields_by_name['receivedPayloadBytes']._options = None
  _globals['_ONUGEMPORTHISTORYDATA'].fields_by_name['receivedPayloadBytes']._serialized_options = b'\030\001'
  _globals['_ONUGEMPORTHISTORYDATA'].fields_by_name['transmittedPayloadBytes']._options = None
  _globals['_ONUGEMPORTHISTORYDATA'].fields_by_name['transmittedPayloadBytes']._serialized_options = b'\030\001'
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['correctedBytes']._options = None
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['correctedBytes']._serialized_options = b'\030\001'
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['correctedCodeWords']._options = None
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['correctedCodeWords']._serialized_options = b'\030\001'
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['totalCodeWords']._options = None
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['totalCodeWords']._serialized_options = b'\030\001'
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['uncorrectableCodeWords']._options = None
  _globals['_GETONUFECHISTORYRESPONSE'].fields_by_name['uncorrectableCodeWords']._serialized_options = b'\030\001'
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS_ADDITIONALSTATSENTRY']._options = None
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS_ADDITIONALSTATSENTRY']._serialized_options = b'8\001'
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS_ADDITIONALSTATSENTRY']._options = None
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS_ADDITIONALSTATSENTRY']._serialized_options = b'8\001'
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS_ADDITIONALSTATSENTRY']._options = None
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS_ADDITIONALSTATSENTRY']._serialized_options = b'8\001'
  _globals['_VALUESET']._serialized_start=134
  _globals['_VALUESET']._serialized_end=210
  _globals['_VALUETYPE']._serialized_start=212
  _globals['_VALUETYPE']._serialized_end=256
  _globals['_VALUETYPE_TYPE']._serialized_start=225
  _globals['_VALUETYPE_TYPE']._serialized_end=256
  _globals['_VALUESPECIFIER']._serialized_start=258
  _globals['_VALUESPECIFIER']._serialized_end=328
  _globals['_RETURNVALUES']._serialized_start=330
  _globals['_RETURNVALUES']._serialized_end=411
  _globals['_GETDISTANCEREQUEST']._serialized_start=413
  _globals['_GETDISTANCEREQUEST']._serialized_end=454
  _globals['_GETDISTANCERESPONSE']._serialized_start=456
  _globals['_GETDISTANCERESPONSE']._serialized_end=495
  _globals['_GETONUUNIINFOREQUEST']._serialized_start=497
  _globals['_GETONUUNIINFOREQUEST']._serialized_end=537
  _globals['_GETONUUNIINFORESPONSE']._serialized_start=540
  _globals['_GETONUUNIINFORESPONSE']._serialized_end=1117
  _globals['_GETONUUNIINFORESPONSE_CONFIGURATIONIND']._serialized_start=778
  _globals['_GETONUUNIINFORESPONSE_CONFIGURATIONIND']._serialized_end=972
  _globals['_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE']._serialized_start=974
  _globals['_GETONUUNIINFORESPONSE_ADMINISTRATIVESTATE']._serialized_end=1045
  _globals['_GETONUUNIINFORESPONSE_OPERATIONALSTATE']._serialized_start=1047
  _globals['_GETONUUNIINFORESPONSE_OPERATIONALSTATE']._serialized_end=1117
  _globals['_GETOLTPORTCOUNTERS']._serialized_start=1120
  _globals['_GETOLTPORTCOUNTERS']._serialized_end=1285
  _globals['_GETOLTPORTCOUNTERS_PORTTYPE']._serialized_start=1216
  _globals['_GETOLTPORTCOUNTERS_PORTTYPE']._serialized_end=1285
  _globals['_GETOLTPORTCOUNTERSRESPONSE']._serialized_start=1288
  _globals['_GETOLTPORTCOUNTERSRESPONSE']._serialized_end=1580
  _globals['_GETONUPONOPTICALINFO']._serialized_start=1582
  _globals['_GETONUPONOPTICALINFO']._serialized_end=1643
  _globals['_GETONUPONOPTICALINFORESPONSE']._serialized_start=1646
  _globals['_GETONUPONOPTICALINFORESPONSE']._serialized_end=1811
  _globals['_GETONUETHERNETBRIDGEPORTHISTORY']._serialized_start=1814
  _globals['_GETONUETHERNETBRIDGEPORTHISTORY']._serialized_end=1978
  _globals['_GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION']._serialized_start=1922
  _globals['_GETONUETHERNETBRIDGEPORTHISTORY_DIRECTION']._serialized_end=1978
  _globals['_GETONUETHERNETBRIDGEPORTHISTORYRESPONSE']._serialized_start=1981
  _globals['_GETONUETHERNETBRIDGEPORTHISTORYRESPONSE']._serialized_end=2387
  _globals['_GETONUALLOCGEMHISTORYREQUEST']._serialized_start=2389
  _globals['_GETONUALLOCGEMHISTORYREQUEST']._serialized_end=2458
  _globals['_ONUGEMPORTHISTORYDATA']._serialized_start=2461
  _globals['_ONUGEMPORTHISTORYDATA']._serialized_end=2729
  _globals['_ONUALLOCHISTORYDATA']._serialized_start=2731
  _globals['_ONUALLOCHISTORYDATA']._serialized_end=2786
  _globals['_ONUALLOCGEMHISTORYDATA']._serialized_start=2789
  _globals['_ONUALLOCGEMHISTORYDATA']._serialized_end=2924
  _globals['_GETONUALLOCGEMHISTORYRESPONSE']._serialized_start=2926
  _globals['_GETONUALLOCGEMHISTORYRESPONSE']._serialized_end=3024
  _globals['_GETONUFECHISTORY']._serialized_start=3026
  _globals['_GETONUFECHISTORY']._serialized_end=3083
  _globals['_GETONUFECHISTORYRESPONSE']._serialized_start=3086
  _globals['_GETONUFECHISTORYRESPONSE']._serialized_end=3391
  _globals['_GETONUCOUNTERSREQUEST']._serialized_start=3393
  _globals['_GETONUCOUNTERSREQUEST']._serialized_end=3449
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST']._serialized_start=3451
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMREQUEST']._serialized_end=3562
  _globals['_GETRXPOWERREQUEST']._serialized_start=3564
  _globals['_GETRXPOWERREQUEST']._serialized_end=3616
  _globals['_GETOLTRXPOWERREQUEST']._serialized_start=3618
  _globals['_GETOLTRXPOWERREQUEST']._serialized_end=3676
  _globals['_GETPONSTATSREQUEST']._serialized_start=3678
  _globals['_GETPONSTATSREQUEST']._serialized_end=3749
  _globals['_GETPONSTATSRESPONSE']._serialized_start=3751
  _globals['_GETPONSTATSRESPONSE']._serialized_end=3837
  _globals['_GETNNISTATSREQUEST']._serialized_start=3839
  _globals['_GETNNISTATSREQUEST']._serialized_end=3910
  _globals['_GETNNISTATSRESPONSE']._serialized_start=3912
  _globals['_GETNNISTATSRESPONSE']._serialized_end=3998
  _globals['_GETONUSTATSFROMOLTREQUEST']._serialized_start=4000
  _globals['_GETONUSTATSFROMOLTREQUEST']._serialized_end=4058
  _globals['_ONUGEMPORTINFOFROMOLT']._serialized_start=4060
  _globals['_ONUGEMPORTINFOFROMOLT']._serialized_end=4170
  _globals['_ONUALLOCIDINFOFROMOLT']._serialized_start=4172
  _globals['_ONUALLOCIDINFOFROMOLT']._serialized_end=4229
  _globals['_ONUALLOCGEMSTATSFROMOLTRESPONSE']._serialized_start=4232
  _globals['_ONUALLOCGEMSTATSFROMOLTRESPONSE']._serialized_end=4375
  _globals['_GETONUSTATSFROMOLTRESPONSE']._serialized_start=4377
  _globals['_GETONUSTATSFROMOLTRESPONSE']._serialized_end=4476
  _globals['_GETONUCOUNTERSRESPONSE']._serialized_start=4479
  _globals['_GETONUCOUNTERSRESPONSE']._serialized_end=5777
  _globals['_OMCIETHERNETFRAMEEXTENDEDPM']._serialized_start=5780
  _globals['_OMCIETHERNETFRAMEEXTENDEDPM']._serialized_end=6191
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE']._serialized_start=6194
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE']._serialized_end=6508
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT']._serialized_start=6460
  _globals['_GETOMCIETHERNETFRAMEEXTENDEDPMRESPONSE_FORMAT']._serialized_end=6508
  _globals['_RXPOWER']._serialized_start=6510
  _globals['_RXPOWER']._serialized_end=6590
  _globals['_GETOLTRXPOWERRESPONSE']._serialized_start=6592
  _globals['_GETOLTRXPOWERRESPONSE']._serialized_end=6673
  _globals['_GETRXPOWERRESPONSE']._serialized_start=6675
  _globals['_GETRXPOWERRESPONSE']._serialized_end=6783
  _globals['_GETONUOMCITXRXSTATSREQUEST']._serialized_start=6785
  _globals['_GETONUOMCITXRXSTATSREQUEST']._serialized_end=6852
  _globals['_GETONUOMCITXRXSTATSRESPONSE']._serialized_start=6855
  _globals['_GETONUOMCITXRXSTATSRESPONSE']._serialized_end=7175
  _globals['_GETONUOMCIACTIVEALARMSREQUEST']._serialized_start=7177
  _globals['_GETONUOMCIACTIVEALARMSREQUEST']._serialized_end=7247
  _globals['_ALARMDATA']._serialized_start=7249
  _globals['_ALARMDATA']._serialized_end=7334
  _globals['_GETONUOMCIACTIVEALARMSRESPONSE']._serialized_start=7336
  _globals['_GETONUOMCIACTIVEALARMSRESPONSE']._serialized_end=7413
  _globals['_GETOFFLOADEDAPPSSTATISTICSREQUEST']._serialized_start=7416
  _globals['_GETOFFLOADEDAPPSSTATISTICSREQUEST']._serialized_end=7600
  _globals['_GETOFFLOADEDAPPSSTATISTICSREQUEST_OFFLOADEDAPP']._serialized_start=7530
  _globals['_GETOFFLOADEDAPPSSTATISTICSREQUEST_OFFLOADEDAPP']._serialized_end=7600
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE']._serialized_start=7603
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE']._serialized_end=9539
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS']._serialized_start=7898
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS']._serialized_end=8408
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS_ADDITIONALSTATSENTRY']._serialized_start=8354
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV4RASTATS_ADDITIONALSTATSENTRY']._serialized_end=8408
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS']._serialized_start=8411
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS']._serialized_end=8986
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS_ADDITIONALSTATSENTRY']._serialized_start=8354
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_DHCPV6RASTATS_ADDITIONALSTATSENTRY']._serialized_end=8408
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS']._serialized_start=8989
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS']._serialized_end=9530
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS_ADDITIONALSTATSENTRY']._serialized_start=8354
  _globals['_GETOFFLOADEDAPPSSTATISTICSRESPONSE_PPPOEIASTATS_ADDITIONALSTATSENTRY']._serialized_end=8408
  _globals['_GETVALUEREQUEST']._serialized_start=9542
  _globals['_GETVALUEREQUEST']._serialized_end=10585
  _globals['_GETVALUERESPONSE']._serialized_start=10588
  _globals['_GETVALUERESPONSE']._serialized_end=12062
  _globals['_GETVALUERESPONSE_STATUS']._serialized_start=11825
  _globals['_GETVALUERESPONSE_STATUS']._serialized_end=11874
  _globals['_GETVALUERESPONSE_ERRORREASON']._serialized_start=11877
  _globals['_GETVALUERESPONSE_ERRORREASON']._serialized_end=12050
  _globals['_APPOFFLOADCONFIG']._serialized_start=12064
  _globals['_APPOFFLOADCONFIG']._serialized_end=12175
  _globals['_APPOFFLOADONUCONFIG']._serialized_start=12178
  _globals['_APPOFFLOADONUCONFIG']._serialized_end=12366
  _globals['_APPOFFLOADONUCONFIG_PERUNICONFIG']._serialized_start=12287
  _globals['_APPOFFLOADONUCONFIG_PERUNICONFIG']._serialized_end=12366
  _globals['_SETVALUEREQUEST']._serialized_start=12369
  _globals['_SETVALUEREQUEST']._serialized_end=12567
  _globals['_SETVALUERESPONSE']._serialized_start=12570
  _globals['_SETVALUERESPONSE']._serialized_end=12875
  _globals['_SETVALUERESPONSE_STATUS']._serialized_start=11825
  _globals['_SETVALUERESPONSE_STATUS']._serialized_end=11874
  _globals['_SETVALUERESPONSE_ERRORREASON']._serialized_start=12753
  _globals['_SETVALUERESPONSE_ERRORREASON']._serialized_end=12875
  _globals['_SINGLEGETVALUEREQUEST']._serialized_start=12877
  _globals['_SINGLEGETVALUEREQUEST']._serialized_end=12963
  _globals['_SINGLEGETVALUERESPONSE']._serialized_start=12965
  _globals['_SINGLEGETVALUERESPONSE']._serialized_end=13036
  _globals['_SINGLESETVALUEREQUEST']._serialized_start=13038
  _globals['_SINGLESETVALUEREQUEST']._serialized_end=13124
  _globals['_SINGLESETVALUERESPONSE']._serialized_start=13126
  _globals['_SINGLESETVALUERESPONSE']._serialized_end=13197
  _globals['_EXTENSION']._serialized_start=13200
  _globals['_EXTENSION']._serialized_end=13379
# @@protoc_insertion_point(module_scope)
